# Copyright 2021 CR-Suite Development Team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Utilities for generating test data
"""

# pylint: disable=W0611

from cr.sparse._src.data.synthetic.random import (
    sparse_normal_representations,
    sparse_biuniform_representations,
    sparse_spikes,
    index_sets,
    points_orthogonal_to
)

from cr.sparse._src.data.synthetic.subspaces import (
    random_subspaces,
    random_subspaces_jit,
    uniform_points_on_subspaces,
    uniform_points_on_subspaces_jit,
    two_subspaces_at_angle,
    two_subspaces_at_angle_jit,
    three_subspaces_at_angle,
    three_subspaces_at_angle_jit
)

# Block sparsity
from cr.sparse._src.data.synthetic.random import (
    sparse_normal_blocks
)
